<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

/**
 * Main daltech Core Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */
final class Daltech_Extension
{

	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '7.0';

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Elementor_Test_Extension The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Elementor_Test_Extension An instance of the class.
	 */
	public static function instance()
	{

		if (is_null(self::$_instance)) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct()
	{
		add_action('plugins_loaded', [$this, 'init']);
	}


	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init()
	{

		// Check if Elementor installed and activated
		if (!did_action('elementor/loaded')) {
			add_action('admin_notices', [$this, 'admin_notice_missing_main_plugin']);
			return;
		}

		// Check for required Elementor version
		if (!version_compare(ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=')) {
			add_action('admin_notices', [$this, 'admin_notice_minimum_elementor_version']);
			return;
		}

		// Check for required PHP version
		if (version_compare(PHP_VERSION, self::MINIMUM_PHP_VERSION, '<')) {
			add_action('admin_notices', [$this, 'admin_notice_minimum_php_version']);
			return;
		}

		// Add Plugin actions
		add_action('elementor/widgets/register', [$this, 'init_widgets']);



		// Register Widget Styles
		add_action('elementor/frontend/after_enqueue_styles', [$this, 'enqueue_widget_styles']);
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'enqueue_widget_styles']);

		// category register
		add_action('elementor/elements/categories_registered', [$this, 'daltech_elementor_widget_categories']);
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin()
	{

		if (isset($_GET['activate'])) unset($_GET['activate']);

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__('"%1$s" requires "%2$s" to be installed and activated.', 'daltech'),
			'<strong>' . esc_html__('Daltech Core', 'daltech') . '</strong>',
			'<strong>' . esc_html__('Elementor', 'daltech') . '</strong>'
		);

		printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version()
	{

		if (isset($_GET['activate'])) unset($_GET['activate']);

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__('"%1$s" requires "%2$s" version %3$s or greater.', 'daltech'),
			'<strong>' . esc_html__('Daltech Core', 'daltech') . '</strong>',
			'<strong>' . esc_html__('Elementor', 'daltech') . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version()
	{

		if (isset($_GET['activate'])) unset($_GET['activate']);

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__('"%1$s" requires "%2$s" version %3$s or greater.', 'daltech'),
			'<strong>' . esc_html__('Daltech Core', 'daltech') . '</strong>',
			'<strong>' . esc_html__('PHP', 'daltech') . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
	}

	public function enqueue_widget_styles()
	{
		wp_enqueue_style('daltech-flaticons', DALTECH_PLUGDIRURI . 'assets/fonts/flaticon-set.css');
	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init_widgets()
	{

		// ------------------------------------------start header file------------------------------------------start //

		// Include Widget files
		require_once(DALTECH_ADDONS . '/widgets/daltech-slider.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-about.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-features.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-services.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-brand.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-call-to-action.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-team.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-text-slider.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-case-studies.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-counter.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-testimonial.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-blog.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-contact.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-trusted-client.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-working-process.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-faq.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-grow.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-pricing.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-manage-it.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-service-menu.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-project.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-project-detials-navigation.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-team-detials.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-team-skill.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-topbar.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-header.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-footer-subscribe.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-footer-about.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-footer-menu.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-footer-contact.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-footer-app.php');
		require_once(DALTECH_ADDONS . '/widgets/daltech-footer-copyright.php');

		// Register widget
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Slider());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Feature());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_About());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Service());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Brand());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Call_To_Action());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Team());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Text_Slider());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Case_Studies());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Counter());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Testimonial());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Blog());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Contact_Form());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Trusted_Client());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Working_Process());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Faq());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Grow());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Pricing());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Manage_It());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Service_Sidebar_Menu());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Project());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Project_Details_Navigation());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Team_Details());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Team_Skill());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Topbar());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Header());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Footer_Subscribe());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Footer_About());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Footer_Menu());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Footer_Contact());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Footer_App());
		\Elementor\Plugin::instance()->widgets_manager->register(new \Daltech_Footer_Copyright());
	}




	function daltech_elementor_widget_categories($elements_manager)
	{
		$elements_manager->add_category(
			'daltech',
			[
				'title' => __('daltech', 'daltech'),
				'icon' 	=> 'fa fa-plug',
			]
		);
		$elements_manager->add_category(
			'daltech_footer_elements',
			[
				'title' => __('daltech Footer Elements', 'daltech'),
				'icon' 	=> 'fa fa-plug',
			]
		);

		$elements_manager->add_category(
			'daltech_header_elements',
			[
				'title' => __('daltech Header Elements', 'daltech'),
				'icon' 	=> 'fa fa-plug',
			]
		);
	}
}

daltech_Extension::instance();
